@@ -9,7 +9,6 @@ import mock
 
 MOCK_MODULES = [
     "scanpy",
-    "rpy2",
     "joblib",
     "tqdm",
     "scikit-misc",
@@ -20,21 +19,17 @@ MOCK_MODULES = [
     "adjustText",
     "statsmodels.stats.multitest",
     "statsmodels.formula.api",
+    "statsmodels.api",
     "igraph",
     "statsmodels.stats.weightstats",
     "skmisc.loess",
     "statsmodels.stats.multitest",
-    "rpy2.robjects",
-    "rpy2.robjects.packages",
-    "rpy2.rinterface",
     "scanpy.plotting._utils",
     "scanpy.plotting._tools.scatterplots",
     "plotly.express",
     "plotly.graph_objects",
-    "elpigraph",
     "phenograph",
     "sklearn.preprocessing",
-    "cellrank",
     "tqdm",
 ]
 for mod_name in MOCK_MODULES:
@@ -76,6 +71,7 @@ extensions = [
     "sphinx_copybutton",
     "nbsphinx",
     "scanpydoc",
+    "docutils",
 ]
 
 ogp_site_url = "https://scfates.readthedocs.io/"
@@ -94,6 +90,10 @@ intersphinx_mapping = dict(
     python=("https://docs.python.org/3", None),
     anndata=("https://anndata.readthedocs.io/en/latest/", None),
     scanpy=("https://scanpy.readthedocs.io/en/latest/", None),
+    cuml=("https://docs.rapids.ai/api/cuml/stable/", None),
+    sklearn=("https://scikit-learn.org/stable/", None),
+    cugraph=("https://docs.rapids.ai/api/cugraph/stable/", None),
+    scipy=("https://docs.scipy.org/doc/scipy/reference/", None),
 )
 
 templates_path = ["_templates"]
