@@ -24,48 +24,10 @@ from tqdm import tqdm
 
 from .. import logging as logg
 from .. import settings
-from .utils import getpath, ProgressParallel, get_X
+from .utils import getpath, ProgressParallel, get_X, importeR
 
-try:
-    from rpy2.robjects import pandas2ri, Formula
-    from rpy2.robjects.packages import importr
-    import rpy2.rinterface
-
-    pandas2ri.activate()
-except Exception as e:
-    warnings.warn(
-        'Cannot compute gene expression trends without installing rpy2. \
-        \nPlease use "pip3 install rpy2" to install rpy2'
-    )
-    warnings.warn(e.__doc__)
-    warnings.warn(e.message)
-
-
-if not shutil.which("R"):
-    warnings.warn(
-        "R installation is necessary for computing gene expression trends. \
-        \nPlease install R and try again"
-    )
-
-try:
-    rstats = importr("stats")
-except Exception as e:
-    warnings.warn(
-        "R installation is necessary for computing gene expression trends. \
-        \nPlease install R and try again"
-    )
-    print(e.__doc__)
-    print(e.message)
-
-try:
-    rmgcv = importr("mgcv")
-except Exception as e:
-    warnings.warn(
-        'R package "mgcv" is necessary for computing gene expression trends. \
-        \nPlease install gam from https://cran.r-project.org/web/packages/gam/ and try again'
-    )
-    print(e.__doc__)
-    print(e.message)
+Rpy2, R, rstats, rmgcv, Formula = importeR("performing bifurcation analysis")
+check = [type(imp) == str for imp in [Rpy2, R, rstats, rmgcv, Formula]]
 
 
 def test_fork(
@@ -118,6 +80,12 @@ def test_fork(
 
     """
 
+    if any(check):
+        idx = np.argwhere(
+            [type(imp) == str for imp in [Rpy2, R, rstats, rmgcv, Formula]]
+        ).min()
+        raise Exception(np.array([Rpy2, R, rstats, rmgcv, Formula])[idx])
+
     adata = adata.copy() if copy else adata
 
     genes = adata.var_names if features is None else features
@@ -129,6 +97,7 @@ def test_fork(
     uns_temp = adata.uns.copy()
 
     dct = graph["milestones"]
+    dct_rev = dict(zip(dct.values(), dct.keys()))
 
     keys = np.array(list(dct.keys()))
     vals = np.array(list(dct.values()))
@@ -163,16 +132,15 @@ def test_fork(
         )
         img.add_edges(edges)
 
-        def get_branches(i):
-            x = vpath[i][1:]
-            segs = graph["pp_info"].loc[x, :].seg.unique()
-            df_sub = df.loc[df.seg.isin(segs), :].copy(deep=True)
-            df_sub.loc[:, "i"] = i
-            return df_sub
+        def get_branches(m):
+            leave = adata.uns["graph"]["milestones"][m]
+            ddf = getpath(img, root, adata.uns["graph"]["tips"], leave, graph, df)
+            ddf["i"] = adata.uns["graph"]["milestones"][m]
+            return ddf
+
+        brcells = pd.concat([get_branches(m) for m in milestones])
+        brcells = brcells.loc[brcells.index.drop_duplicates(False)]
 
-        brcells = pd.concat(
-            list(map(get_branches, range(len(vpath)))), axis=0, sort=False
-        )
         matw = None
         if matw is None:
             brcells["w"] = 1
@@ -202,9 +170,11 @@ def test_fork(
             desc="    Differential expression",
         )(delayed(gt_fun)(data[d]) for d in range(len(data)))
 
-        fork_stat = fork_stat + [
-            pd.DataFrame(stat, index=genes, columns=milestones + ["de_p"])
-        ]
+        stat = pd.concat(stat, axis=1).T
+        stat.index = genes
+        stat.columns = [dct_rev[c] for c in stat.columns[: len(milestones)]] + ["de_p"]
+
+        fork_stat = fork_stat + [stat]
 
         topleave = fork_stat[m].iloc[:, :-1].idxmax(axis=1).apply(lambda mil: dct[mil])
 
@@ -332,18 +302,18 @@ def gt_fun(data):
     #
 
     global rmgcv
-    global rstats
 
-    def gamfit(sdf):
-        m = rmgcv.gam(
-            Formula("exp ~ s(t)+s(t,by=as.factor(i))+as.factor(i)"),
-            data=sdf,
-            weights=sdf["w"],
-        )
-        return rmgcv.summary_gam(m)[3][1]
+    m = rmgcv.gam(
+        Formula("exp ~ s(t)+s(t,by=as.factor(i))+as.factor(i)"),
+        data=sdf,
+        weights=sdf["w"],
+    )
 
     Amps = sdf.groupby("i").apply(lambda x: np.mean(x.exp))
-    return (Amps - Amps.max()).tolist() + [gamfit(sdf)]
+    res = Amps - Amps.max()
+    res["de_p"] = rmgcv.summary_gam(m)[3][1]
+
+    return res
 
 
 def test_upreg(data):
@@ -496,6 +466,14 @@ def activation(
 
     """
 
+    if any(check):
+        idx = np.argwhere(
+            [type(imp) == str for imp in [Rpy2, R, rstats, rmgcv, Formula]]
+        ).min()
+        raise Exception(np.array([Rpy2, R, rstats, rmgcv, Formula])[idx])
+
+    adata = adata.copy() if copy else adata
+
     graph = adata.uns["graph"]
 
     logg.info("testing activation", reset=True)
