@@ -21,49 +21,11 @@ from tqdm import tqdm
 
 from .. import logging as logg
 from .. import settings
-from .utils import getpath, get_X
+from .utils import getpath, get_X, importeR
 
 
-try:
-    from rpy2.robjects import pandas2ri, Formula
-    from rpy2.robjects.packages import importr
-    import rpy2.rinterface
-
-    pandas2ri.activate()
-except Exception as e:
-    warnings.warn(
-        'Cannot compute gene expression trends without installing rpy2. \
-        \nPlease use "pip3 install rpy2" to install rpy2'
-    )
-    print(e.__doc__)
-    print(e.message)
-
-
-if not shutil.which("R"):
-    warnings.warn(
-        "R installation is necessary for computing gene expression trends. \
-        \nPlease install R and try again"
-    )
-
-try:
-    rstats = importr("stats")
-except Exception as e:
-    warnings.warn(
-        "R installation is necessary for computing gene expression trends. \
-        \nPlease install R and try again"
-    )
-    print(e.__doc__)
-    print(e.message)
-
-try:
-    rmgcv = importr("mgcv")
-except Exception as e:
-    warnings.warn(
-        'R package "mgcv" is necessary for computing gene expression trends. \
-        \nPlease install gam from https://cran.r-project.org/web/packages/gam/ and try again'
-    )
-    print(e.__doc__)
-    print(e.message)
+Rpy2, R, rstats, rmgcv, Formula = importeR("fitting associated features")
+check = [type(imp) == str for imp in [Rpy2, R, rstats, rmgcv, Formula]]
 
 
 def fit(
@@ -118,6 +80,12 @@ def fit(
 
     """
 
+    if any(check):
+        idx = np.argwhere(
+            [type(imp) == str for imp in [Rpy2, R, rstats, rmgcv, Formula]]
+        ).min()
+        raise Exception(np.array([Rpy2, R, rstats, rmgcv, Formula])[idx])
+
     adata = adata.copy() if copy else adata
 
     if "signi" not in adata.var.columns:
